DbWalletCashuProof class
- Annotations
-
- @Entity()
Constructors
- DbWalletCashuProof({required String keysetId, required int amount, required String secret, required String unblindedSig, required String state})
- DbWalletCashuProof.fromNdk(dynamic ndkM)
-
factory
Properties
- amount ↔ int
-
getter/setter pair
- dbId ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- keysetId ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secret ↔ String
-
getter/setter pair
- state ↔ String
-
getter/setter pair
- unblindedSig ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNdk(
) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited