DbKeyValue class

Annotations

Constructors

DbKeyValue({required String key, String? value})

Properties

dbId ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited