DbWallet class

Annotations

Constructors

DbWallet({required String id, required String type, required List<String> supportedUnits, required String name, required String metadataJsonString})
DbWallet.fromNdk(Wallet ndkM)
factory

Properties

dbId ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
metadataJsonString ↔ String
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedUnits ↔ List<String>
getter/setter pair
type ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNdk() → Wallet
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited