DbCashuMintInfo_ class
DbCashuMintInfo entity fields to define ObjectBox queries.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
contactJson
→ QueryStringProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.contactJson.
final
-
dbId
→ QueryIntegerProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.dbId.
final
-
description
→ QueryStringProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.description.
final
-
descriptionLong
→ QueryStringProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.descriptionLong.
final
-
iconUrl
→ QueryStringProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.iconUrl.
final
-
motd
→ QueryStringProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.motd.
final
-
name
→ QueryStringProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.name.
final
-
nutsJson
→ QueryStringProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.nutsJson.
final
-
time
→ QueryIntegerProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.time.
final
-
tosUrl
→ QueryStringProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.tosUrl.
final
-
urls
→ QueryStringVectorProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.urls.
final
-
version
→ QueryStringProperty<
DbCashuMintInfo> -
See DbCashuMintInfo.version.
final