DbWalletCahsuKeyset_ class
DbWalletCahsuKeyset entity fields to define ObjectBox queries.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
active
→ QueryBooleanProperty<
DbWalletCahsuKeyset> -
See DbWalletCahsuKeyset.active.
final
-
dbId
→ QueryIntegerProperty<
DbWalletCahsuKeyset> -
See DbWalletCahsuKeyset.dbId.
final
-
fetchedAt
→ QueryIntegerProperty<
DbWalletCahsuKeyset> -
See DbWalletCahsuKeyset.fetchedAt.
final
-
id
→ QueryStringProperty<
DbWalletCahsuKeyset> -
See DbWalletCahsuKeyset.id.
final
-
inputFeePPK
→ QueryIntegerProperty<
DbWalletCahsuKeyset> -
See DbWalletCahsuKeyset.inputFeePPK.
final
-
mintKeyPairs
→ QueryStringVectorProperty<
DbWalletCahsuKeyset> -
See DbWalletCahsuKeyset.mintKeyPairs.
final
-
mintUrl
→ QueryStringProperty<
DbWalletCahsuKeyset> -
See DbWalletCahsuKeyset.mintUrl.
final
-
unit
→ QueryStringProperty<
DbWalletCahsuKeyset> -
See DbWalletCahsuKeyset.unit.
final