DbWalletTransaction_ class
DbWalletTransaction entity fields to define ObjectBox queries.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
changeAmount
→ QueryIntegerProperty<
DbWalletTransaction> -
See DbWalletTransaction.changeAmount.
final
-
completionMsg
→ QueryStringProperty<
DbWalletTransaction> -
See DbWalletTransaction.completionMsg.
final
-
dbId
→ QueryIntegerProperty<
DbWalletTransaction> -
See DbWalletTransaction.dbId.
final
-
id
→ QueryStringProperty<
DbWalletTransaction> -
See DbWalletTransaction.id.
final
-
initiatedDate
→ QueryIntegerProperty<
DbWalletTransaction> -
See DbWalletTransaction.initiatedDate.
final
-
metadataJsonString
→ QueryStringProperty<
DbWalletTransaction> -
See DbWalletTransaction.metadataJsonString.
final
-
state
→ QueryStringProperty<
DbWalletTransaction> -
See DbWalletTransaction.state.
final
-
transactionDate
→ QueryIntegerProperty<
DbWalletTransaction> -
See DbWalletTransaction.transactionDate.
final
-
unit
→ QueryStringProperty<
DbWalletTransaction> -
See DbWalletTransaction.unit.
final
-
walletId
→ QueryStringProperty<
DbWalletTransaction> -
See DbWalletTransaction.walletId.
final
-
walletType
→ QueryStringProperty<
DbWalletTransaction> -
See DbWalletTransaction.walletType.
final