DbWallet_ class
DbWallet entity fields to define ObjectBox queries.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
dbId
→ QueryIntegerProperty<
DbWallet> -
See DbWallet.dbId.
final
-
id
→ QueryStringProperty<
DbWallet> -
See DbWallet.id.
final
-
metadataJsonString
→ QueryStringProperty<
DbWallet> -
See DbWallet.metadataJsonString.
final
-
name
→ QueryStringProperty<
DbWallet> -
See DbWallet.name.
final
-
supportedUnits
→ QueryStringVectorProperty<
DbWallet> -
See DbWallet.supportedUnits.
final
-
type
→ QueryStringProperty<
DbWallet> -
See DbWallet.type.
final