syncClockTimestamp static method

int syncClockTimestamp(
  1. int syncClockValue
)

Gets the "raw" timestamp (milliseconds since epoch) from the given sync clock value.

Note that sync clock values are assigned by ObjectBox and are not to be interpreted on their own. Use this function to extract a meaningful timestamp from a sync clock value (e.g. stored in a @SyncClock field).

Implementation

static int syncClockTimestamp(int syncClockValue) =>
    C.sync_clock_timestamp(syncClockValue);