syncClockTimestampCorrected static method

int syncClockTimestampCorrected(
  1. int syncClockValue
)

Gets the corrected timestamp (milliseconds since epoch) from the given sync clock value.

Like syncClockTimestamp, but applies any time correction if present in the sync clock value. However, for most cases, it will return the same value as syncClockTimestamp.

Implementation

static int syncClockTimestampCorrected(int syncClockValue) =>
    C.sync_clock_timestamp_corrected(syncClockValue);