applyFilterVariables method
void
applyFilterVariables()
Applies all pending Sync filter variable updates (from putFilterVariable and removeFilterVariable calls).
If the client is connected, sends the updated variables to the server. If the client is not connected, the updated variables will be included in the next login message.
See also putFilterVariable, removeFilterVariable and removeAllFilterVariables.
Implementation
void applyFilterVariables() {
checkObx(C.sync_filter_variables_apply(_ptr));
}