cancelUpdates method
Cancels updates from the server so that it will stop sending updates.
Returns true if the request was likely sent (client is logged in).
See also requestUpdates.
Implementation
bool cancelUpdates() => checkObxSuccess(C.sync_updates_cancel(_ptr));