putFilterVariable method
Adds or replaces a Sync filter variable value for the given name.
Note: If the client is already logged in, this change is not applied until applyFilterVariables is called. This allows to put or remove multiple variables before applying all changes. Filter variables set before login (before calling start) are automatically applied.
Eventually, existing values for the same name are replaced.
Sync client filter variables can be used in server-side Sync filters to filter out objects that do not match the filter.
See also removeFilterVariable, removeAllFilterVariables and applyFilterVariables.
Implementation
void putFilterVariable(String name, String value) {
withNativeString(
name,
(nameCStr) => withNativeString(
value,
(valueCStr) => checkObx(
C.sync_filter_variables_put(_ptr, nameCStr, valueCStr))));
}