requestUpdates method

bool requestUpdates({
  1. required bool subscribeForFuturePushes,
})

Requests updates from the server since we last synchronized.

Set subscribeForFuturePushes to true to also subscribe for future updates as they come in. Call cancelUpdates to stop receiving updates.

Returns true if the request was likely sent (client is logged in).

Implementation

bool requestUpdates({required bool subscribeForFuturePushes}) =>
    checkObxSuccess(C.sync_updates_request(_ptr, subscribeForFuturePushes));