stop method

void stop()

Stops this sync client and closes the connection to the server.

Does nothing if already stopped. Can be started again. Use close to fully release resources when done with the client.

Implementation

void stop() {
  checkObx(C.sync_stop(_ptr));
}