SyncCredentials class

Credentials used to authenticate a SyncClient against an ObjectBox Sync Server.

Use one of the factory methods to create credentials matching your server configuration.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

googleAuthString(String data) SyncCredentials
Google authentication using the ID token as a string.
googleAuthUint8List(Uint8List data) SyncCredentials
Google authentication using the ID token as raw bytes.
jwtAccessToken(String jwtAccessToken) SyncCredentials
JSON Web Token (JWT): an access token that is used to access resources.
jwtCustomToken(String jwtCustomToken) SyncCredentials
JSON Web Token (JWT): a token that is neither an ID, access, nor refresh token.
jwtIdToken(String jwtIdToken) SyncCredentials
JSON Web Token (JWT): an ID token that typically provides identity information about the authenticated user.
jwtRefreshToken(String jwtRefreshToken) SyncCredentials
JSON Web Token (JWT): a refresh token that is used to obtain a new access token.
none() SyncCredentials
No credentials - usually only for development purposes with a server configured to accept all connections without authentication.
sharedSecretString(String data) SyncCredentials
Shared secret authentication using a string.
sharedSecretUint8List(Uint8List data) SyncCredentials
Shared secret authentication using raw bytes.
userAndPassword(String user, String password) SyncCredentials
Username and password authentication.