SyncPrecedence class

An annotation to mark a field of a synced Entity class as the sync precedence. See SyncPrecedence.new.

Constructors

SyncPrecedence()
Marks an int (64-bit integer) field of a synced Entity class as the "sync precedence" to customize Sync conflict resolution.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited