SyncPrecedence constructor
const
SyncPrecedence()
Marks an int (64-bit integer) field of a synced Entity class as the "sync precedence" to customize Sync conflict resolution.
Developer-assigned precedence values are then used to resolve conflicts via "higher precedence wins". Defining and assigning precedence values are completely in the hands of the developer (the ObjectBox user).
There can be only one sync precedence per sync entity type.
Typically, it is combined with a SyncClock, with the latter being the tie-breaker for equal precedence values.
Implementation
const SyncPrecedence();