DbNip05 class

Annotations

Constructors

DbNip05({required String pubKey, required String nip05, bool valid = false, int? networkFetchTime, List<String> relays = const []})
DbNip05.fromNdk(Nip05 ndkNip05)
factory

Properties

dbId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
networkFetchTime int?
getter/setter pair
nip05 String
getter/setter pair
pubKey String
getter/setter pair
relays List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valid bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNdk() → Nip05
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited