DbWalletTransaction class
- Annotations
-
- @Entity()
Constructors
- DbWalletTransaction({required String id, required String walletId, required int changeAmount, required String unit, required String walletType, required String state, String? completionMsg, int? transactionDate, int? initiatedDate, required String metadataJsonString})
- DbWalletTransaction.fromNdk(WalletTransaction ndkM)
-
factory
Properties
- changeAmount ↔ int
-
getter/setter pair
- completionMsg ↔ String?
-
getter/setter pair
- dbId ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- initiatedDate ↔ int?
-
getter/setter pair
- metadataJsonString ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String
-
getter/setter pair
- transactionDate ↔ int?
-
getter/setter pair
- unit ↔ String
-
getter/setter pair
- walletId ↔ String
-
getter/setter pair
- walletType ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toNdk(
) → WalletTransaction -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited